#include <stdio.h>
#include <libmc.h>

int main() 
{
  MCAgency_t agency;
  int local_port = 5051;
  
  agency = MC_Initialize(local_port, NULL);

  sleep(10);
  MC_End(agency);
  return 0;
}
